@@ -1,8 +1,7 @@
-# $Id: CBC.pm 1829 2005-05-25 21:51:40Z btrott $
-
 package Convert::PEM::CBC;
 use strict;
 
+our $VERSION = '0.09'; # VERSION
 use Carp qw( croak );
 use Digest::MD5 qw( md5 );
 use base qw( Class::ErrorHandler );
@@ -115,6 +114,7 @@ Convert::PEM::CBC - Cipher Block Chaining Mode implementation
                          Passphrase => 'foo'
            );
 
+    my $plaintext = 'foo bar baz';
     $cbc->encrypt($plaintext);
 
 =head1 DESCRIPTION
